ExtractionMode

Enum ExtractionMode 

#[non_exhaustive]
pub enum ExtractionMode { Auto, Native, ForcedTool, }
Controls how structured data is extracted from a provider response.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Auto

Automatically select the best strategy based on provider capabilities. Prefers Native when structured output is explicitly supported, otherwise falls back to ForcedTool when tool calls are explicitly supported.



Native

Use the provider’s built-in structured output / JSON mode.



ForcedTool

Inject a synthetic tool and force the provider to call it, extracting the structured data from the tool call arguments.